@@ -37,7 +37,7 @@ using namespace std;
 Aureport::Aureport(QWidget *parent, const char *name): QDialog(parent, name)
 {
         aureportLabel = new QLabel(tr("Report about"),this);
-        startdayLabel = new QLabel(tr("start-day(1/1/2010)"),this);
+        startdayLabel = new QLabel(tr("start-day ex.(1/1/2013)"),this);
         starttimeLabel = new QLabel(tr("start-time"),this);
         enddayLabel = new QLabel(tr("end-day"),this);
         endtimeLabel = new QLabel(tr("end-time"),this);
@@ -231,7 +231,6 @@ void Aureport::aureport_button_clicked()
 	}
 
 	aureport_process = new AureportProcess(this);
-	//connect(aureport_process, SIGNAL(aureport_process_close_button_clicked()), this, SLOT(close()));
 	connect(closeButton, SIGNAL(clicked()), aureport_process, SLOT(close()));
 	aureport_process->setCaption(tr(aureport_str_pp_str));
 	aureport_process->show();
