@@ -39,7 +39,7 @@ Ausearch::Ausearch(QWidget *parent, const char *name): QDialog(parent, name)
 {
 	//setCaption(tr("Ausearch"));
 	ausearchLabel = new QLabel(tr("Search about"),this);
-	startdayLabel = new QLabel(tr("start-day(1/1/2010)"),this);
+	startdayLabel = new QLabel(tr("start-day ex.(1/1/2013)"),this);
 	starttimeLabel = new QLabel(tr("start-time"),this);
 	enddayLabel = new QLabel(tr("end-day"),this);
 	endtimeLabel = new QLabel(tr("end-time"),this);
