@@ -70,10 +70,10 @@ private:
         QRadioButton *deRadioButton;
         QRadioButton *frRadioButton;
         QRadioButton *auRadioButton;
-        QRadioButton *fifteenRadioButton;
-        QRadioButton *sixteenRadioButton;
-        QRadioButton *seventeenRadioButton;
-        QRadioButton *eighteenRadioButton;
+        QRadioButton *new4RadioButton;
+        QRadioButton *new3RadioButton;
+        QRadioButton *new2RadioButton;
+        QRadioButton *newRadioButton;
 
         QString semanageEditLineEdit_str_add_restorecon;
 	QPushButton *downloadButton;
